@@ -164,6 +164,7 @@ func addCommands() {
 	DoitCmd.AddCommand(OneClicks())
 	DoitCmd.AddCommand(Monitoring())
 	DoitCmd.AddCommand(Serverless())
+	DoitCmd.AddCommand(Tokens())
 }
 
 func computeCmd() *Command {
@@ -217,6 +218,12 @@ func requiredOpt() flagOpt {
 	}
 }
 
+func hiddenFlag() flagOpt {
+	return func(c *Command, name, key string) {
+		c.Flags().MarkHidden(name)
+	}
+}
+
 // AddStringFlag adds a string flag to a command.
 func AddStringFlag(cmd *Command, name, shorthand, dflt, desc string, opts ...flagOpt) {
 	fn := flagName(cmd, name)
