@@ -25,6 +25,7 @@ mockgen -source images.go -package=mocks ImageService > mocks/ImageService.go
 mockgen -source invoices.go -package=mocks InvoicesService > mocks/InvoicesService.go
 mockgen -source kubernetes.go -package=mocks KubernetesService > mocks/KubernetesService.go
 mockgen -source load_balancers.go -package=mocks LoadBalancersService > mocks/LoadBalancersService.go
+mockgen -source oauth.go -package=mocks OAuthService > mocks/OAuthService.go
 mockgen -source projects.go -package=mocks ProjectsService > mocks/ProjectsService.go
 mockgen -source regions.go -package=mocks RegionsService > mocks/RegionsService.go
 mockgen -source registry.go -package=mocks RegistryService > mocks/RegistryService.go
@@ -42,3 +43,4 @@ mockgen -source monitoring.go -package=mocks MonitoringService > mocks/Monitorin
 mockgen -source reserved_ip_actions.go -package=mocks ReservedIPActionsService > mocks/ReservedIPActionsService.go
 mockgen -source reserved_ips.go -package=mocks ReservedIPsService > mocks/ReservedIPsService.go
 mockgen -source serverless.go -package=mocks ServerlessService > mocks/ServerlessService.go
+mockgen -source tokens.go -package=mocks TokensService > mocks/TokensService.go
